@@ -103,6 +103,8 @@ class Config(object):
                 value = 1
             elif self.params[p] == False:
                 value = 0
+            elif self.params[p] == None:
+                continue
             else:
                 value = self.params[p]
 
@@ -295,6 +297,9 @@ class Config(object):
         if self.conf.has_option('params', 'header_template'):
             self.params['header_template'] = self.conf.get('params', 'header_template')
 
+        if self.conf.has_option('params', 'proxy'):
+            self.params['proxy'] = self.conf.get('params', 'proxy')
+
     def check_google_tokens(self):
         try:
             from shorter.googl import GooglUrlShorter
