@@ -67,6 +67,7 @@ key = {
     'get_fav':           'B',
     'delete_fav':        '^B',
     'thread':            'T',
+    'waterline':         'w',
 }
 
 params = {
@@ -87,6 +88,7 @@ params = {
     'url_shorter':          'ur1ca',
     'logging_level':        3,
     'header_template':      ' {nick}{retweeted}{retweeter} - {time}{reply} {retweet_count} ',
+    'proxy':                None,
 }
 
 filter = {
