@@ -66,11 +66,20 @@ class Help(object):
         self.display_help_item('unfollow_selected', _('Unfollow selected twitter'))
         self.display_help_item('follow', _('Follow a twitter'))
         self.display_help_item('unfollow', _('Unfollow a twitter'))
+
+        # Favorite
+        self.display_division('Favorite')
+        self.display_help_item('fav', _('Bookmark selected tweet'))
+        self.display_help_item('get_fav', _('Go to favorite timeline'))
+        self.display_help_item('delete_fav', _('Delete an favorite tweet'))
+
         # Others
         self.display_division(_('Others'))
         self.display_help_item('quit', _('Leave Tyrs'))
         self.display_help_item('openurl', _('Open URL in browser'))
+        self.display_help_item('open_image', _('Open image in browser'))
         self.display_help_item('redraw', _('Redraw the screen'))
+        self.display_help_item('thread', _('Open thread seltected'))
 
         self.interface.screen.refresh()
         self.interface.screen.getch()
