@@ -46,11 +46,12 @@ class Interface(object):
         self.timelines  = tyrs.container['timelines']
         self.buffers    = tyrs.container['buffers']
         tyrs.container.add('interface', self)
-        self.last_read_home = self.conf.load_last_read()
+        self.update_last_read_home()
         self.api.set_interface()
         self.resize_event     = False
         self.regex_retweet     = re.compile('^RT @\w+:')
         self.refresh_token    = False
+        self.stoped = False
         self.buffer           = 'home'
         self.charset = sys.stdout.encoding
         # resize event
@@ -58,6 +59,7 @@ class Interface(object):
         self.init_screen()
         self.first_update()
 
+
     def init_screen(self):
 
         self.screen = curses.initscr()
@@ -505,7 +507,7 @@ class Interface(object):
         origin = str(origin)
         return origin
 
-    def tear_down(self, *dummy):
+    def tear_down(self):
         '''Last function call when quiting, restore some defaults params'''
         self.screen.keypad(0)
         curses.echo()
@@ -577,9 +579,12 @@ class Interface(object):
         urls = get_urls(self.current_status().text)
         for url in urls:
             try:
-                os.system(self.conf.params['openurl_command'] % url)
+                os.system(self.conf.params['openurl_command'] % url + '> /dev/null 2>&1')
             except:
                 pass 
 
+    def update_last_read_home(self):
+        self.last_read_home = self.conf.load_last_read()
+
     def current_user_info(self):
         User(self.current_status().user)
