@@ -30,24 +30,25 @@ class Timeline(object):
 
     def append_new_statuses(self, retreive):
         retreive = self.filter_statuses(retreive)
-        # Fresh new start.
+
         if retreive:
-            if self.statuses == []:
+            if len(self.statuses) == 0:
                 self.statuses = retreive
-                self.update_counter()
-            # This mean there is no new status, we just leave then.
-            elif retreive[0].id == self.statuses[0].id:
-                pass
-            # We may just don't have tweets, in case for DM for example
-            elif len(retreive) == 0:
-                pass
-            # Finally, we append tweets
             else:
-                for i in range(len(retreive)):
-                    if retreive[i].id == self.statuses[0].id:
-                        self.statuses = retreive[:i] + self.statuses
-                        self.current += len(retreive[:i])
-                self.update_counter()
+                current_id = self.statuses[self.current].id
+                for i, status in enumerate(self.statuses):
+                    if retreive[-1].id == status.id:
+                        try:
+                            self.statuses = retreive + self.statuses[i+1:]
+                            self.find_current(current_id)
+                        except IndexError:
+                            self.statuses = retreive
+            self.update_counter()
+
+    def find_current(self, current_id):
+        for i, status in enumerate(self.statuses):
+            if status.id == current_id:
+                self.current = i
 
     def filter_statuses(self, statuses):
         filters = []
