@@ -18,12 +18,13 @@
    Tyrs
 
    @author:     Nicolas Paris <nicolas.caen@gmail.com>
-   @version:    0.4.1
-   @date:       27/07/2011
+   @version:    0.5.0
+   @date:       06/11/2011
    @licence:    GPLv3
 
 '''
 
+import sys
 import utils
 import config
 import locale
@@ -31,6 +32,7 @@ import tweets
 import argparse
 import gettext
 import curses.wrapper
+from urllib2 import URLError
 from keys import Keys
 from timeline import Timeline
 from update import UpdateThread 
@@ -59,11 +61,9 @@ def main():
 
     utils.set_console_title()
     init_conf()
-    curses.wrapper(init_tyrs)
-    print 'Waiting for thread stopping...'
-    return 0
+    init_tyrs()
 
-def init_tyrs(scr):
+def init_tyrs():
     init_timelines()
     init_api()
     init_interface()
@@ -77,7 +77,11 @@ def init_conf():
 def init_api():
     api = tweets.Tweets()
     container.add('api', api)
-    api.authentication()
+    try:
+        api.authentication()
+    except URLError, e:
+        print 'error:%s' % e
+        sys.exit(1)
 
 def init_interface():
     user_interface = Interface()
